==> sayaka-3.6.4.tar.gz: sayaka-3.6.4/src/Image.cpp <==
/*
 * Copyright (C) 2021 Tetsuya Isaki
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#include "Image.h"

//
// 画像
//

// コンストラクタ (空)
Image::Image()
{
}

// コンストラクタ (サイズ指定)
Image::Image(int width_, int height_)
{
	Create(width_, height_);
}

// デストラクタ
Image::~Image()
{
}

// 初期化
void
Image::Create(int width_, int height_)
{
	size.w = width_;
	size.h = height_;
	buf.resize(GetStride() * GetHeight());
}

//
// 画像ローダの基本クラス
//

// コンストラクタ
ImageLoader::ImageLoader(InputStream *stream_, const Diag& diag_)
{
	stream = stream_;
	diag = diag_;
}

// デストラクタ
ImageLoader::~ImageLoader()
{
}

==> sayaka-3.7.2.tar.gz: sayaka-3.7.2/src/Image.cpp <==
/*
 * Copyright (C) 2021 Tetsuya Isaki
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#include "Image.h"
#include "PeekableStream.h"

//
// 画像
//

// コンストラクタ (空)
Image::Image()
{
}

// コンストラクタ (サイズ指定)
Image::Image(int width_, int height_)
{
	Create(width_, height_);
}

// デストラクタ
Image::~Image()
{
}

// 初期化
void
Image::Create(int width_, int height_)
{
	size.w = width_;
	size.h = height_;
	buf.resize(GetStride() * GetHeight());
}

//
// 画像ローダの基本クラス
//

// コンストラクタ
ImageLoader::ImageLoader(PeekableStream *stream_, const Diag& diag_)
{
	stream = stream_;
	diag = diag_;
}

// デストラクタ
ImageLoader::~ImageLoader()
{
}
